<?php

declare(strict_types=1);

namespace Drupal\lms_messages;

use Drupal\grequest\Plugin\Group\Relation\GroupMembershipRequest;
use Drupal\group\Entity\GroupRelationshipInterface;

/**
 * Methods for messages on membership request operations.
 */
final class GroupMembershipRequestHelper {

  /**
   * Check if new group relationship applies for a message.
   */
  public static function getNewRelationshipParameters(GroupRelationshipInterface $group_relationship): array {
    if (
      $group_relationship->getPluginId() !== 'group_membership_request' ||
      $group_relationship->getGroupTypeId() !== 'lms_course'
    ) {
      return [];
    }

    $course = $group_relationship->getGroup();
    $message_parameters = [];
    foreach ($course->getMembers() as $teacher_membership) {
      $message_parameters[] = [
        'template' => MessageService::SUPPORTED_TEMPLATES['new_request'],
        'uid' => $teacher_membership->getUser()->id(),
        'course' => $course->id(),
        'user' => $group_relationship->getEntityId(),
      ];
    }
    return $message_parameters;
  }

  /**
   * Check if updated group relationship applies for a message.
   */
  public static function getUpdatedRelationshipParameters(GroupRelationshipInterface $group_relationship): array {
    if (
      $group_relationship->getPluginId() !== 'group_membership_request' ||
      $group_relationship->getGroupTypeId() !== 'lms_course' ||
      !$group_relationship->original instanceof GroupRelationshipInterface
    ) {
      return [];
    }

    if (
      $group_relationship->get(GroupMembershipRequest::STATUS_FIELD)->value === GroupMembershipRequest::REQUEST_APPROVED &&
      // @todo https://www.drupal.org/node/3295826
      $group_relationship->original->get(GroupMembershipRequest::STATUS_FIELD)->value !== GroupMembershipRequest::REQUEST_APPROVED
    ) {
      return [
        [
          'template' => MessageService::SUPPORTED_TEMPLATES['approved_request'],
          'uid' => $group_relationship->getEntityId(),
          'course' => $group_relationship->getGroupId(),
        ],
      ];
    }
    if (
      $group_relationship->get(GroupMembershipRequest::STATUS_FIELD)->value === GroupMembershipRequest::REQUEST_REJECTED &&
      $group_relationship->original->get(GroupMembershipRequest::STATUS_FIELD)->value !== GroupMembershipRequest::REQUEST_REJECTED
    ) {
      return [
        [
          'template' => MessageService::SUPPORTED_TEMPLATES['rejected_request'],
          'uid' => $group_relationship->getEntityId(),
          'course' => $group_relationship->getGroupId(),
        ],
      ];
    }

    return [];
  }

}
